---
title: 'QA/QC Pipeline for Video/Audio/Sensor'
tags:
  - Visualising sensor data, videos and audios
  - Analyzing sensor data, videos and audios
  - Python toolbox
  - Quality Assessment
  - Wearable Sensors
  - Sensor feature extraction
  - time series analysis
authors:
  - name: Abhishek Pratap
    affiliation: 1
  - name: Ramzi Halabi
    affiliation: 1
  - name: Rahavi Selvarajan
    affiliation: 1
  - name: Jana Kabrit
    affiliation: 1
  - name: Zixiong Lin
    affiliation: 1
affiliations:
 - name: AID4MH, Krembil Centre for Neuroinformatics, CAMH, Toronto
   index: 1
date: 30 June, 2022
bibliography: paper.bib
---

# Optional fields if submitting to a AAS journal too, see this blog post:

# https://blog.joss.theoj.org/2018/12/a-new-collaboration-with-aas-publiyshing

aas-doi: 10.3847/xxxxx <- update this with the DOI from AAS once you know it.
aas-journal: Astrophysical Journal <- The name of the AAS journal.

---

# Summary

....

# Statement of need

`QA-Module` is an ...affiliated Python package for .... Python
enables wrapping low-level languages (e.g., C) for speed without losing
flexibility or ease-of-use in the user-interface. The API for `QA-Module` was
designed to provide a class-based and user-friendly interface to fast implementations of common operations ..... `QA- Module` also relies heavily on and
interfaces well with the ... `...` package LINK and
`..`).

`QA-module` was designed to be used by researchers, developers, and
students for .... It has already been
used in a number of scientific publications ... The combination of speed,
design, and support for .. functionality in `QA-Module` will enable exciting
... of forthcoming data releases from ...

# Citations

Citations to entries in paper.bib should be in
[rMarkdown](http://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html)
format.

If you want to cite a software repository URL (e.g. something on GitHub without a preferred
citation) then you can do it with the example BibTeX entry below for @fidgit.

For a quick reference, the following citation commands can be used:

- `@author:2001` -> "Author et al. (2001)"
- `[@author:2001]` -> "(Author et al., 2001)"
- `[@author1:2001; @author2:2001]` -> "(Author1 et al., 2001; Author2 et al., 2002)"

# Figures

Figures can be included like this:
![Caption for example figure.\label{fig:example}](figure.png)
and referenced from text using \autoref{fig:example}.

Figure sizes can be customized by adding an optional second parameter:
![Caption for example figure.](figure.png){ width=20% }

# Acknowledgements

We acknowledge contributions from Brigitta Sipocz, Syrtis Major, and Semyeong
Oh, and support from Kathryn Johnston during the genesis of this project.

# References
